==> kubernetes-model-scheduling-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassFluent<A extends io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getDescription();
  public A withDescription(java.lang.String description);
  public java.lang.Boolean hasDescription();
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0);
  public java.lang.Boolean getGlobalDefault();
  public A withGlobalDefault(java.lang.Boolean globalDefault);
  public java.lang.Boolean hasGlobalDefault();
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public java.lang.String getPreemptionPolicy();
  public A withPreemptionPolicy(java.lang.String preemptionPolicy);
  public java.lang.Boolean hasPreemptionPolicy();
  
  /**
   * Method is deprecated. use withPreemptionPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewPreemptionPolicy(java.lang.String arg0);
  public java.lang.Integer getValue();
  public A withValue(java.lang.Integer value);
  public java.lang.Boolean hasValue();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> kubernetes-model-scheduling-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassFluent.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityClassFluent<A extends io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getDescription();
  public A withDescription(java.lang.String description);
  public java.lang.Boolean hasDescription();
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0);
  public java.lang.Boolean getGlobalDefault();
  public A withGlobalDefault(java.lang.Boolean globalDefault);
  public java.lang.Boolean hasGlobalDefault();
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public java.lang.String getPreemptionPolicy();
  public A withPreemptionPolicy(java.lang.String preemptionPolicy);
  public java.lang.Boolean hasPreemptionPolicy();
  
  /**
   * Method is deprecated. use withPreemptionPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewPreemptionPolicy(java.lang.String arg0);
  public java.lang.Integer getValue();
  public A withValue(java.lang.Integer value);
  public java.lang.Boolean hasValue();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
